.. _tutorials:

*********
Tutorials
*********

In this section, we provide a series of tutorials to demonstrate how ``zenopy``
can be used in practice.

.. toctree::
    :maxdepth: 5
    :titlesonly:
    :glob:
       
    tutorial_*